@@ -3,19 +3,17 @@
     Copyright (C) 2007 Lubos Lunak (l.lunak@kde.org)
 
     This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
+    modify it under the terms of the GNU Lesser General Public
     License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
+    version 2.1 of the License, or (at your option) any later version.
 
     This library is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
+    Lesser General Public License for more details.
 
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    You should have received a copy of the GNU Lesser General Public
+    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 */
 /*
  * kwindowinfo.h. Part of the KDE project.
@@ -56,7 +54,7 @@ class KWindowInfoPrivate;
  * demands attention window state:
  *
  * @code
- * QWidget *widget = new QWidget(Q_NULLPTR);
+ * QWidget *widget = new QWidget(nullptr);
  * widget->show(); // ensures native window gets created
  * connect(KWindowSystem::self(), static_cast<void (KWindowSystem::*)(WId, unsigned int)>(&KWindowSystem::windowChanged),
  *        [window](WId winId, unsigned int properties) {
@@ -85,7 +83,7 @@ public:
      * @param properties Bitmask of NET::Property
      * @param properties2 Bitmask of NET::Property2
      */
-    KWindowInfo(WId window, NET::Properties properties, NET::Properties2 properties2 = 0);
+    KWindowInfo(WId window, NET::Properties properties, NET::Properties2 properties2 = NET::Properties2());
     ~KWindowInfo();
     /**
      * Returns false if this window info is not valid.
@@ -109,7 +107,7 @@ public:
      * Requires NET::WMState passed as properties parameter to the constructor.
      *
      * @code
-     * QWidget *window = new QWidget(Q_NULLPTR);
+     * QWidget *window = new QWidget(nullptr);
      * window->show();
      * KWindowInfo info(window->winId(), NET::WMState);
      * if (info.valid())
@@ -124,7 +122,7 @@ public:
      *
      * Requires NET::WMState passed as properties parameter to the constructor.
      * @code
-     * QWidget *window = new QWidget(Q_NULLPTR);
+     * QWidget *window = new QWidget(nullptr);
      * window->show();
      * KWindowInfo info(window->winId(), NET::WMState);
      * if (info.valid())
@@ -144,7 +142,7 @@ public:
      * Requires NET::WMState and NET::XAWMState passed as properties parameter to the constructor.
      *
      * @code
-     * QWidget *window = new QWidget(Q_NULLPTR);
+     * QWidget *window = new QWidget(nullptr);
      * window->show();
      * KWindowInfo info(window->winId(), NET::WMState | NET::XAWMState);
      * if (info.valid())
@@ -160,7 +158,7 @@ public:
      * Requires NET::XAWMState passed as properties parameter to the constructor.
      *
      * @code
-     * QWidget *window = new QWidget(Q_NULLPTR);
+     * QWidget *window = new QWidget(nullptr);
      * window->show();
      * KWindowInfo info(window->winId(), NET::XAWMState);
      * if (info.valid())
@@ -178,7 +176,7 @@ public:
      * Requires NET::WM2ExtendedStrut passed as properties2 parameter to the constructor.
      *
      * @code
-     * QWidget *window = new QWidget(Q_NULLPTR);
+     * QWidget *window = new QWidget(nullptr);
      * window->show();
      * KWindowInfo info(window->winId(), 0, NET::WM2ExtendedStrut);
      * if (info.valid())
@@ -193,7 +191,7 @@ public:
      * Requires NET::WMWindowType passed as properties parameter to the constructor.
      *
      * @code
-     * QWidget *window = new QWidget(Q_NULLPTR);
+     * QWidget *window = new QWidget(nullptr);
      * window->show();
      * KWindowInfo info(window->winId(), NET::WMWindowType);
      * if (info.valid())
@@ -212,7 +210,7 @@ public:
      * Requires NET::WMVisibleName passed as properties parameter to the constructor.
      *
      * @code
-     * QWidget *window = new QWidget(Q_NULLPTR);
+     * QWidget *window = new QWidget(nullptr);
      * window->show();
      * KWindowInfo info(window->winId(), NET::WMVisibleName);
      * if (info.valid())
@@ -232,7 +230,7 @@ public:
      * @return the window name with state
      *
      * @code
-     * QWidget *window = new QWidget(Q_NULLPTR);
+     * QWidget *window = new QWidget(nullptr);
      * window->show();
      * KWindowInfo info(window->winId(), NET::WMVisibleName | NET::WMState | NET::XAWMState);
      * if (info.valid())
@@ -251,7 +249,7 @@ public:
      * Requires NET::WMName passed as properties parameter to the constructor.
      *
      * @code
-     * QWidget *window = new QWidget(Q_NULLPTR);
+     * QWidget *window = new QWidget(nullptr);
      * window->show();
      * KWindowInfo info(window->winId(), NET::WMName);
      * if (info.valid())
@@ -269,7 +267,7 @@ public:
      * Requires NET::WMVisibleIconName passed as properties parameter to the constructor.
      *
      * @code
-     * QWidget *window = new QWidget(Q_NULLPTR);
+     * QWidget *window = new QWidget(nullptr);
      * window->show();
      * KWindowInfo info(window->winId(), NET::WMVisibleIconName);
      * if (info.valid())
@@ -288,7 +286,7 @@ public:
      * @return the window iconic name with state
      *
      * @code
-     * QWidget *window = new QWidget(Q_NULLPTR);
+     * QWidget *window = new QWidget(nullptr);
      * window->show();
      * KWindowInfo info(window->winId(), NET::WMVisibleIconName | NET::WMState | NET::XAWMState);
      * if (info.valid())
@@ -306,7 +304,7 @@ public:
      * Requires NET::WMIconName passed as properties parameter to the constructor.
      *
      * @code
-     * QWidget *window = new QWidget(Q_NULLPTR);
+     * QWidget *window = new QWidget(nullptr);
      * window->show();
      * KWindowInfo info(window->winId(), NET::WMIconName);
      * if (info.valid())
@@ -320,7 +318,7 @@ public:
      * Requires NET::WMDesktop passed as properties parameter to the constructor.
      *
      * @code
-     * QWidget *window = new QWidget(Q_NULLPTR);
+     * QWidget *window = new QWidget(nullptr);
      * window->show();
      * KWindowInfo info(window->winId(), NET::WMDesktop);
      * if (info.valid())
@@ -334,7 +332,7 @@ public:
      * Requires NET::WMDesktop passed as properties parameter to the constructor.
      *
      * @code
-     * QWidget *window = new QWidget(Q_NULLPTR);
+     * QWidget *window = new QWidget(nullptr);
      * window->show();
      * KWindowInfo info(window->winId(), NET::WMDesktop);
      * if (info.valid())
@@ -349,7 +347,7 @@ public:
      * Requires NET::WMDesktop passed as properties parameter to the constructor.
      *
      * @code
-     * QWidget *window = new QWidget(Q_NULLPTR);
+     * QWidget *window = new QWidget(nullptr);
      * window->show();
      * KWindowInfo info(window->winId(), NET::WMDesktop);
      * if (info.valid())
@@ -367,7 +365,7 @@ public:
      * Requires NET::WMDesktop passed as properties parameter to the constructor.
      *
      * @code
-     * QWidget *window = new QWidget(Q_NULLPTR);
+     * QWidget *window = new QWidget(nullptr);
      * window->show();
      * KWindowInfo info(window->winId(), NET::WMDesktop);
      * if (info.valid())
@@ -393,7 +391,7 @@ public:
      * Requires NET::WM2Activities passed as properties parameter to the constructor.
      *
      * @code
-     * QWidget *window = new QWidget(Q_NULLPTR);
+     * QWidget *window = new QWidget(nullptr);
      * window->show();
      * KWindowInfo info(window->winId(), 0, NET::WM2Activities);
      * if (info.valid())
@@ -411,7 +409,7 @@ public:
      * Requires NET::WMGeometry passed as properties parameter to the constructor.
      *
      * @code
-     * QWidget *window = new QWidget(Q_NULLPTR);
+     * QWidget *window = new QWidget(nullptr);
      * window->show();
      * KWindowInfo info(window->winId(), NET::WMGeometry);
      * if (info.valid())
@@ -425,7 +423,7 @@ public:
      * Requires NET::WMFrameExtents passed as properties parameter to the constructor.
      *
      * @code
-     * QWidget *window = new QWidget(Q_NULLPTR);
+     * QWidget *window = new QWidget(nullptr);
      * window->show();
      * KWindowInfo info(window->winId(), NET::WMFrameExtents);
      * if (info.valid())
@@ -441,7 +439,7 @@ public:
      * Requires NET::WM2TransientFor passed as properties2 parameter to the constructor.
      *
      * @code
-     * QWidget *window = new QWidget(Q_NULLPTR);
+     * QWidget *window = new QWidget(nullptr);
      * window->show();
      * KWindowInfo info(window->winId(), 0, NET::WM2TransientFor);
      * if (info.valid())
@@ -455,7 +453,7 @@ public:
      * Requires NET::WM2GroupLeader passed as properties2 parameter to the constructor.
      *
      * @code
-     * QWidget *window = new QWidget(Q_NULLPTR);
+     * QWidget *window = new QWidget(nullptr);
      * window->show();
      * KWindowInfo info(window->winId(), 0, NET::WM2GroupLeader);
      * if (info.valid())
@@ -471,7 +469,7 @@ public:
      * Requires NET::WM2WindowClass passed as properties2 parameter to the constructor.
      *
      * @code
-     * QWidget *window = new QWidget(Q_NULLPTR);
+     * QWidget *window = new QWidget(nullptr);
      * window->show();
      * KWindowInfo info(window->winId(), 0, NET::WM2WindowClass);
      * if (info.valid())
@@ -487,7 +485,7 @@ public:
      * Requires NET::WM2WindowClass passed as properties2 parameter to the constructor.
      *
      * @code
-     * QWidget *window = new QWidget(Q_NULLPTR);
+     * QWidget *window = new QWidget(nullptr);
      * window->show();
      * KWindowInfo info(window->winId(), 0, NET::WM2WindowClass);
      * if (info.valid())
@@ -503,7 +501,7 @@ public:
      * Requires NET::WM2WindowRole passed as properties2 parameter to the constructor.
      *
      * @code
-     * QWidget *window = new QWidget(Q_NULLPTR);
+     * QWidget *window = new QWidget(nullptr);
      * window->show();
      * KWindowInfo info(window->winId(), 0, NET::WM2WindowRole);
      * if (info.valid())
@@ -519,7 +517,7 @@ public:
      * Requires NET::WM2ClientMachine passed as properties2 parameter to the constructor.
      *
      * @code
-     * QWidget *window = new QWidget(Q_NULLPTR);
+     * QWidget *window = new QWidget(nullptr);
      * window->show();
      * KWindowInfo info(window->winId(), 0, NET::WM2ClientMachine);
      * if (info.valid())
@@ -536,7 +534,7 @@ public:
      * Requires NET::WM2AllowedActions passed as properties2 parameter to the constructor.
      *
      * @code
-     * QWidget *window = new QWidget(Q_NULLPTR);
+     * QWidget *window = new QWidget(nullptr);
      * window->show();
      * KWindowInfo info(window->winId(), 0, NET::WM2AllowedActions);
      * if (info.valid())
@@ -545,6 +543,46 @@ public:
      */
     bool actionSupported(NET::Action action) const;
 
+    /**
+     * Returns the desktop file name of the window's application if present.
+     *
+     * This is either the base name without full path and without file extension of the
+     * desktop file for the window's application (e.g. "org.kde.foo").
+     *
+     * If the application's desktop file name is not at a standard location it should be
+     * the full path to the desktop file name (e.g. "/opt/kde/share/org.kde.foo.desktop").
+     *
+     * Requires NET::WM2DesktopFileName passed as properties2 parameter to the constructor.
+     *
+     * @code
+     * QWidget *window = new QWidget(nullptr);
+     * window->show();
+     * KWindowInfo info(window->winId(), 0, NET::WM2DesktopFileName);
+     * if (info.valid())
+     *     info.desktopFileName();
+     * @endcode
+     *
+     * @since 5.29
+     **/
+    QByteArray desktopFileName() const;
+
+    /**
+     * Returns the process ID of the window's application if present.
+     *
+     * Requires NET::WMPid passed as properties parameter to the constructor.
+     *
+     * @code
+     * QWidget *window = new QWidget(nullptr);
+     * window->show();
+     * KWindowInfo info(window->winId(), NET::WMPid);
+     * if (info.valid())
+     *     info.desktopFileName();
+     * @endcode
+     *
+     * @since 5.29
+     */
+    int pid() const;
+
     /**
      * Copy constructor.
      */
